pub struct UpstreamPool { /* private fields */ }Expand description
Manages the full set of upstream backends and their health states.
Implementations
Sourceimpl UpstreamPool
impl UpstreamPool
Sourcepub fn from_validated(upstreams: &[ValidatedUpstream]) -> Self
pub fn from_validated(upstreams: &[ValidatedUpstream]) -> Self
Constructs a pool from validated upstream configurations, marking all backends as initially healthy.
Sourcepub fn all(&self) -> &[UpstreamState]
pub fn all(&self) -> &[UpstreamState]
Returns a slice of all backends (healthy and unhealthy).
Sourcepub fn healthy(&self) -> Vec<&UpstreamState>
pub fn healthy(&self) -> Vec<&UpstreamState>
Returns the backends that are currently marked healthy.